==> order-center-domain-2.9.0-CLOUD-20251104.094631-13-sources.jar: com/tydic/dyc/oc/model/aforder/IUocAfOrderModel.java <==
package com.tydic.dyc.oc.model.aforder;

import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.model.aforder.qrybo.*;
import com.tydic.dyc.oc.model.aforder.sub.*;
import com.tydic.dyc.oc.model.saleorder.sub.UocSaleOrderItem;
import com.tydic.dyc.oc.model.shiporder.sub.UocShipOrderItem;
import com.tydic.dyc.oc.service.domainservice.bo.UocAfterOrderFinishConfirmReqBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocAfterOrderSupplierConfirmReqBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocAfterOrderSupplierConfirmRspBo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Optional;

/**
 * 标题:IUocAfOrderModel
 * 说明:售后单
 * 时间:2022/2/23 14:01
 * 作者:罗有
 */

public interface IUocAfOrderModel {

    /**
     * 查询售后单明细
     *
     * @param uocAfOrderItemQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderItem></>
     */
    List<UocAfOrderItem> getAfOrderItemList(UocAfOrderItemQryBo uocAfOrderItemQryBo);

    /**
     * 根据售后单ID查询售后单信息
     *
     * @param uocAfOrderQryBo
     * @return @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrder></>
     */
    UocAfOrder getAfOrderById(UocAfOrderQryBo uocAfOrderQryBo);

    /**
     * 售后单列表查询
     *
     * @param uocAfOrderQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrder></>
     */
    List<UocAfOrder> getAfOrderList(UocAfOrderQryBo uocAfOrderQryBo);

    /**
     * 售后单对象列表查询
     *
     * @param uocAfOrderObjQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderObj></>
     */
    List<UocAfOrderObj> getAfOrderObjList(UocAfOrderObjQryBo uocAfOrderObjQryBo);

    /**
     * 售后单扩展查询
     *
     * @param uocAfOrderMapQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderMap></>
     */
    List<UocAfOrderMap> getAfOrderMapList(UocAfOrderMapQryBo uocAfOrderMapQryBo);

    /**
     * 售后单明细扩展查询
     *
     * @param uocAfItemMapQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfItemMap></>
     */
    List<UocAfItemMap> getAfOrderItemMapList(UocAfItemMapQryBo uocAfItemMapQryBo);

    /**
     * 售后运单信息查询
     *
     * @param uocAfOrderWaybillQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderWaybill></>
     */
    List<UocAfOrderWaybill> getAfOrderWayBillList(UocAfOrderWaybillQryBo uocAfOrderWaybillQryBo);

    /**
     * 获取退货信息
     *
     * @param uocAfOrderReturnAddressQryBo
     * @return com.tydic.dyc.oc.model.aforder.sub.UocAfOrderReturnAdress</>
     */
    UocAfOrderReturnAddress getAfReturnAddress(UocAfOrderReturnAddressQryBo uocAfOrderReturnAddressQryBo);

    /***
     * 创建售后服务申请
     * @param afOrderDo
     * @return
     */
    UocAfOrderDo dealPebTheZoneAfterApplication(UocAfOrderDo afOrderDo, Integer orderSource);


    /**
     * 获取售后服务单编码
     *
     * @param afOrderDo
     * @return
     */
    UocAfOrderDo getAfterOrderNo(UocAfOrderDo afOrderDo, Integer orderSource);

    /**
     * 更新售后主体信息
     *
     * @param uocAfOrderDos
     */
    void updateBatchAfOrderMain(List<UocAfOrderDo> uocAfOrderDos);

    void updateAfOrderMain(UocAfOrderDo uocAfOrderDo);

    void modifyAfOrderExtOrderId(UocAfOrderDo afOrderDo);

    void addWayBill(UocAfOrderWaybill uocAfOrderWaybill);

    void modifyAfOrderState(UocAfOrderDo afOrderDo);


    boolean confirmAfOrderState(UocAfterOrderSupplierConfirmReqBo afOrderDo, Integer flag, UocAfterOrderSupplierConfirmRspBo rspBo);

    void modifyAfterOrderCount(UocAfterOrderFinishConfirmReqBo reqBo);

}

==> order-center-domain-3.0.0-CLOUD-20251113.071850-85-sources.jar: com/tydic/dyc/oc/model/aforder/IUocAfOrderModel.java <==
package com.tydic.dyc.oc.model.aforder;

import com.tydic.dyc.oc.model.aforder.qrybo.*;
import com.tydic.dyc.oc.model.aforder.sub.*;
import com.tydic.dyc.oc.model.saleorder.UocSaleOrderDo;
import com.tydic.dyc.oc.model.saleorder.qrybo.UocSaleOrderQryBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocAfterOrderFinishConfirmReqBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocAfterOrderSupplierConfirmReqBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocAfterOrderSupplierConfirmRspBo;

import java.util.List;

/**
 * 标题:IUocAfOrderModel
 * 说明:售后单
 * 时间:2022/2/23 14:01
 * 作者:罗有
 */

public interface IUocAfOrderModel {

    /**
     * 查询售后单明细
     *
     * @param uocAfOrderItemQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderItem></>
     */
    List<UocAfOrderItem> getAfOrderItemList(UocAfOrderItemQryBo uocAfOrderItemQryBo);

    /**
     * 根据售后单ID查询售后单信息
     *
     * @param uocAfOrderQryBo
     * @return @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrder></>
     */
    UocAfOrder getAfOrderById(UocAfOrderQryBo uocAfOrderQryBo);

    /**
     * 售后单列表查询
     *
     * @param uocAfOrderQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrder></>
     */
    List<UocAfOrder> getAfOrderList(UocAfOrderQryBo uocAfOrderQryBo);

    /**
     * 售后单对象列表查询
     *
     * @param uocAfOrderObjQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderObj></>
     */
    List<UocAfOrderObj> getAfOrderObjList(UocAfOrderObjQryBo uocAfOrderObjQryBo);

    /**
     * 售后单扩展查询
     *
     * @param uocAfOrderMapQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderMap></>
     */
    List<UocAfOrderMap> getAfOrderMapList(UocAfOrderMapQryBo uocAfOrderMapQryBo);

    /**
     * 售后单明细扩展查询
     *
     * @param uocAfItemMapQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfItemMap></>
     */
    List<UocAfItemMap> getAfOrderItemMapList(UocAfItemMapQryBo uocAfItemMapQryBo);

    /**
     * 售后运单信息查询
     *
     * @param uocAfOrderWaybillQryBo
     * @return java.util.List<com.tydic.dyc.oc.model.aforder.sub.UocAfOrderWaybill></>
     */
    List<UocAfOrderWaybill> getAfOrderWayBillList(UocAfOrderWaybillQryBo uocAfOrderWaybillQryBo);

    /***
     * 创建售后服务申请
     * @param afOrderDo
     * @return
     */
    UocAfOrderDo dealPebTheZoneAfterApplication(UocAfOrderDo afOrderDo, Integer orderSource);


    /**
     * 获取售后服务单编码
     *
     * @param afOrderDo
     * @return
     */
    UocAfOrderDo getAfterOrderNo(UocAfOrderDo afOrderDo, Integer orderSource);

    /**
     * 更新售后主体信息
     *
     * @param uocAfOrderDos
     */
    void updateBatchAfOrderMain(List<UocAfOrderDo> uocAfOrderDos);

    void updateAfOrderMain(UocAfOrderDo uocAfOrderDo);

    void modifyAfOrderExtOrderId(UocAfOrderDo afOrderDo);

    void addWayBill(UocAfOrderWaybill uocAfOrderWaybill);

    void modifyAfOrderState(UocAfOrderDo afOrderDo);


    boolean confirmAfOrderState(UocAfterOrderSupplierConfirmReqBo afOrderDo, Integer flag, UocAfterOrderSupplierConfirmRspBo rspBo);

    void modifyAfterOrderCount(UocAfterOrderFinishConfirmReqBo reqBo);

    List<UocAfOrderObj> getAfOrderObjList(UocAfterOrderFinishConfirmReqBo reqBo);
    
    //查询 需要对账电商的售后单列表
    List<UocAfOrderDo> getCheckAfOrders(UocAfOrderDo record);
}
